@@ -15,6 +15,7 @@ def fun_control_init(
     TENSORBOARD_CLEAN=False,
     SUMMARY_WRITER=True,
     accelerator="auto",
+    converters=None,
     data=None,
     data_dir="./data",
     data_module=None,
@@ -26,28 +27,36 @@ def fun_control_init(
     EXPERIMENT_NAME=None,
     fun_evals=15,
     fun_repeats=1,
+    horizon=None,
     infill_criterion="y",
     log_level=50,
     lower=None,
     max_time=1,
+    metric_sklearn=None,
     noise=False,
     n_points=1,
     num_workers=0,
     ocba_delta=0,
+    oml_grace_period=None,
     optimizer=None,
     seed=123,
     show_models=False,
     show_progress=True,
     sigma=0.0,
     surrogate=None,
+    target_column=None,
     task=None,
+    test=None,
     test_seed=1234,
     test_size=0.4,
+    train=None,
     tolerance_x=0,
     upper=None,
     var_name=None,
     var_type=["num"],
     verbosity=0,
+    weights=1.0,
+    weight_coeff=0.0,
 ):
     """Initialize fun_control dictionary.
 
@@ -87,6 +96,8 @@ def fun_control_init(
             The number of function repeats during the optimization. this value does not affect
             the number of the repeats in the initial design (this value can be set in the
             design_control). Default is 1.
+        horizon (int):
+            The horizon of the time series data. Default is None.
         infill_criterion (str):
             Can be `"y"`, `"s"`, `"ei"` (negative expected improvement), or `"all"`. Default is "y".
         log_level (int):
@@ -102,6 +113,8 @@ def fun_control_init(
             lower bound
         max_time (int):
             The maximum time in minutes.
+        metric_sklearn (object):
+            The metric object from the scikit-learn library. Default is None.
         noise (bool):
             Whether the objective function is noiy or not. Default is False.
             Affects the repeat of the function evaluations.
@@ -112,6 +125,8 @@ def fun_control_init(
         ocba_delta (int):
             The number of additional, new points (only used if noise==True) generated by
             the OCBA infill criterion. Default is 0.
+        oml_grace_period (int):
+            The grace period for the OML algorithm. Default is None.
         optimizer (object):
             The optimizer object used for the search on surrogate. Default is None.
         PREFIX (str):
@@ -128,11 +143,15 @@ def fun_control_init(
             Currently only 1-dim functions are supported. Default is `False`.
         surrogate (object):
             The surrogate model object. Default is None.
+        target_column (str):
+            The name of the target column. Default is None.
         task (str):
             The task to perform. It can be either "classification" or "regression".
             Default is None.
         TENSORBOARD_CLEAN (bool):
             Whether to clean (delete) the tensorboard folder or not. Default is False.
+        test (object):
+            The test data set for spotRiver. Default is None.
         test_seed (int):
             The seed to use for the test set. Default is 1234.
         test_size (float):
@@ -142,6 +161,8 @@ def fun_control_init(
             tolerance for new x solutions. Minimum distance of new solutions,
             generated by `suggest_new_X`, to already existing solutions.
             If zero (which is the default), every new solution is accepted.
+        train (object):
+            The training data set for spotRiver. Default is None.
         upper (np.array):
             upper bound
         var_name (list):
@@ -152,6 +173,12 @@ def fun_control_init(
         verbosity (int):
             The verbosity level. Determines print output to console. Higher values
             result in more output. Default is 0.
+        weights (float):
+            The weight coefficient of the objective function. Positive values mean minimization.
+            If set to -1, scores that are better when maximized will be minimized, e.g, accuracy.
+            Can be an array, so that different weights can be used for different (multiple) objectives.
+        weight_coeff (float):
+            Determines how to weight older measures. Default is 1.0. Used in the OML algorithm eval_oml.py.
 
     Returns:
         fun_control (dict):
@@ -175,6 +202,7 @@ def fun_control_init(
                 'devices': "auto",
                 'enable_progress_bar': False,
                 'eval': None,
+                'horizon': 7,
                 'infill_criterion': 'y',
                 'k_folds': None,
                 'loss_function': None,
@@ -189,6 +217,7 @@ def fun_control_init(
                 'n_samples': None,
                 'num_workers': 0,
                 'ocba_delta': 0,
+                'oml_grace_period': None,
                 'optimizer': None,
                 'path': None,
                 'prep_model': None,
@@ -264,6 +293,7 @@ def fun_control_init(
         "eval": None,
         "fun_evals": fun_evals,
         "fun_repeats": fun_repeats,
+        "horizon": horizon,
         "infill_criterion": infill_criterion,
         "k_folds": 3,
         "log_graph": False,
@@ -272,7 +302,7 @@ def fun_control_init(
         "lower": lower,
         "max_time": max_time,
         "metric_river": None,
-        "metric_sklearn": None,
+        "metric_sklearn": metric_sklearn,
         "metric_torch": None,
         "metric_params": {},
         "model_dict": {},
@@ -281,6 +311,7 @@ def fun_control_init(
         "n_samples": None,
         "num_workers": num_workers,
         "ocba_delta": ocba_delta,
+        "oml_grace_period": oml_grace_period,
         "optimizer": optimizer,
         "path": None,
         "prep_model": None,
@@ -293,18 +324,19 @@ def fun_control_init(
         "sigma": sigma,
         "spot_tensorboard_path": spot_tensorboard_path,
         "spot_writer": spot_writer,
-        "target_column": None,
+        "target_column": target_column,
+        "task": task,
+        "test": test,
         "test_seed": test_seed,
         "test_size": test_size,
         "tolerance_x": tolerance_x,
-        "train": None,
-        "test": None,
-        "task": task,
+        "train": train,
         "upper": upper,
         "var_name": var_name,
         "var_type": var_type,
         "verbosity": verbosity,
-        "weights": 1.0,
+        "weights": weights,
+        "weight_coeff": weight_coeff,
     }
     # lower = X_reshape(lower)
     # fun_control.update({"lower": lower})
